@@ -47,13 +47,30 @@ def base_64_to_file(contents,file=None):
     else:
         return string_contents
 
-def get_date_from_repo_commit(repo, commit):    
-    return get_date_from_commit_url("https://api.github.com/repos/{0}/commits/{1}".format(repo,commit))
+def get_date_from_repo_commit(repo, commit,headers={}):    
+    return get_date_from_commit_url("https://api.github.com/repos/{0}/commits/{1}".format(repo,commit,headers))
     
-def get_date_from_commit_url(url):
-    req = requests.get(url).json()
+def get_date_from_commit_url(url,headers={}):
+    req = requests.get(url,headers=headers).json()
     return datetime.datetime.strptime(req['commit']['committer']['date'], "%Y-%m-%dT%H:%M:%SZ")
 
+def get_commits_of_repo(repo,from_date=None,to_date=None,headers={}):
+    params = []
+    if from_date:
+        params += ["since={0}".format(from_date)]
+    if from_date:
+        params += ["until={0}".format(to_date)]
+    request_url = "https://api.github.com/repos/{0}/commits?{1}".format(repo, '&'.join(params))
+    req = requests.get(request_url, headers=headers)
+    return req.json()
+
+def filewebinfo(repo, filepath, lineno=None,commit='master'):
+    baseurl = "https://github.com/{0}/blob/{1}/{2}".format(repo,commit,filepath)
+    if lineno:
+        baseurl += "#L{0}".format(lineno)
+    
+    return baseurl
+
 class githuburl(object):
   def __init__(self,token=None,verify=True,wait_lambda=None,logging_lambda=None):
     self.token = token
@@ -469,4 +486,4 @@ class GRepo(object):
         except Exception as e:
             print(f"Issue with creating the jsonl file: {e}")
 
-        return contents
\ No newline at end of file
+        return contents
